@@ -1,6 +1,6 @@
 var Mat3_8h =
 [
-    [ "Mat3< T >", "classopenvdb_1_1v12__1_1_1math_1_1Mat3.html", "classopenvdb_1_1v12__1_1_1math_1_1Mat3" ],
+    [ "Mat3&lt; T &gt;", "classopenvdb_1_1v12__1_1_1math_1_1Mat3.html", "classopenvdb_1_1v12__1_1_1math_1_1Mat3" ],
     [ "openvdb::v12_1::math::Mat3d", "namespaceopenvdb_1_1v12__1_1_1math.html#a29742c92282b86aa2885165d7464ac3a", null ],
     [ "openvdb::v12_1::math::Mat3f", "namespaceopenvdb_1_1v12__1_1_1math.html#ab2766fbde36a3b616af0f852c3dff5ff", null ],
     [ "openvdb::v12_1::math::Mat3s", "namespaceopenvdb_1_1v12__1_1_1math.html#a85b140686e0a81e6b7e47e021428005e", null ],
